@@ -1,5 +1,5 @@
 # -*- shell-script -*-
-#   Copyright (C) 2008, 2010 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2008, 2010, 2011 Rocky Bernstein rocky@gnu.org
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -108,7 +108,7 @@ columnize() {
     done
 }
 
-if [[ $0 == *columnize.sh ]] ; then 
+if [[ $0 == ${BASH_SOURCE[0]} ]] ; then 
     #
     print_columns() {
 	unset columnized
