@@ -89,7 +89,7 @@ test_breakpoint() {
     _Dbg_clear_all_brkpt
 }
 
-abs_top_srcdir=/src/external-vcs/bashdb
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
 # Make sure @abs_top_srcrdir@ has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
