@@ -38,11 +38,11 @@ test_columnized()
 
 }
 
-if [ '/src/external-vcs/bashdb' = '' ] ; then
+if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-vcs/bashdb
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
 # Make sure $abs_top_srcrdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
