@@ -5,8 +5,20 @@ this_script=test-filecache.sh
 # Test _Dbg_get_source_line
 test_get_source_line()
 {
+    _Dbg_set_highlight=0
+    _Dbg_source_line='no good'
     _Dbg_get_source_line 2 $this_script
     assertEquals '# -*- shell-script -*-' "$_Dbg_source_line"
+
+    # Getting sourceline with highlight set but we don't have 
+    # the highlighted cached should fall back back to getting the line
+    # without highlight.
+    _Dbg_source_line='no good'
+    _Dbg_set_highlight=1
+    _Dbg_get_source_line 2 $this_script
+    assertEquals \
+	"Requested highlight, it's not cached - fallback no highlight"\
+	'# -*- shell-script -*-' "$_Dbg_source_line"
 }
 
 # Test readin and maxline
@@ -51,12 +63,12 @@ test_check_line()
     _Dbg_check_line 10000 $shunit_file
 }
 
-if [ '/src/external-vcs/bashdb' = '' ] ; then
+if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
 
-abs_top_srcdir=/src/external-vcs/bashdb
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
 # Make sure $abs_top_srcrdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
